#############################################################
####### Electoral Systems Around the World: 1946-2011 #######
####### Nils-Christian Bormann & Matt Golder	      #######
####### Electoral Studies			      #######
####### Replication Code for Graphs & Figures         #######
#############################################################


#############################################################
### Prepare the data
rm(list=ls())
setwd("C:/Uni/Data/Eclipse_Workbench/Electoral Systems Data")
data <- read.csv("es_data-v2_0.csv", header=T, sep=",")
attach(data)

## Data Prep
# Decade dummy
decade <- rep(0, dim(data)[1])
decade[year > 1940 & year <= 1950] <- 1
decade[year > 1950 & year <= 1960] <- 2
decade[year > 1960 & year <= 1970] <- 3
decade[year > 1970 & year <= 1980] <- 4
decade[year > 1980 & year <= 1990] <- 5
decade[year > 1990 & year <= 2000] <- 6
decade[year > 2000 & year <= 2010] <- 7
decade[year > 2010] <- 8

#############################################################
### Statistics in text by section
## Abstract
# number of new presidential elections (2001-2011)
npresn <- table(presidential[year > 2000])[2]
# number of new legislative elections (2001-2011)
nlegn <- table(presidential[year > 2000])[1]
# total number of new elections (2001-2011)
nelecn <- nlegn + npresn

## Introduction
# Number of total presidential elections
npres <- table(presidential)[2]

# Number of total legislative elections
nleg <- table(presidential)[1]


## Democratic Elections
# Number of presidential elections from 2001-2010
npres00 <- table(presidential[year > 2000 & year < 2011])[2]

# Number of parliamentary elections from 2001-2010
nleg00 <- table(presidential[year > 2000 & year < 2011])[1]

# Countries that held elections for the first time between 2001 and 2010
newelec <- unique(data$ccode[data$year>2000])[!is.element(unique(data$ccode[data$year>2000]), unique(data$ccode[data$year<=2000]))]
newdems <- unique(country[is.element(ccode, newelec)])
newyear <- rep(0, length(newdems))
for(i in 1:length(newdems)){
	newyear[i] <- min(year[country==newdems[i]])
}
cbind(as.character(newdems), newyear)

## Legislative Elections
# Proportion of electoral systems by decade can be taken from code for figure 3 below

## Some additional information
# total number of all elections in dataset
nelec <- nleg + npres
# number of presidential/legislative elections in 1990s and 2000s
npres90 <- table(presidential[year <= 2000 & year > 1990])[2] 
nleg90 <- table(presidential[year <= 2000 & year > 1990])[1]



#############################################################
### Figure 1
## Data Prep
presdec <- c(table(decade[presidential==1]))
names(presdec) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s", "2010s")

legdec <- c(table(decade[presidential==0]))
names(legdec) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s", "2010s")

legpresdec <- rbind(legdec, presdec)
legpresdec[1,]/apply(legpresdec,2,sum)
legpresdec[2,]/apply(legpresdec,2,sum)

# Number of legislative and presidential elections by decade 
legpresdec <- legpresdec[,-c(1,8)]

## Graph
par(mar=c(2.1,4.1,1.1,0.1))
barplot(legpresdec,
		ylab=list("Number of Elections", cex=1.3),
		ylim=c(0,300),
		beside=T,
		col=c("grey30", "grey80"),
		legend = c("Legislative", "Presidential"),
		args.legend=list(x="topleft", cex=1.2)
)


#############################################################
### Figure 3
## Data Prep
legislative_type[legislative_type < 0] <- NA	
syscount <- matrix(0, length(table(legislative_type)), length(table(decade[year < 2011])))
sum(syscount)
rownames(syscount) <- c("Majoritarian", "PR", "Mixed")
colnames(syscount) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")


for(j in 1:length(colnames(syscount))){
		syscount[,j] <- table(legislative_type[decade==j & presidential==0])
}


sysrel <- matrix(0, dim(syscount)[1], dim(syscount)[2])
for(i in 1:dim(syscount)[1]){
	sysrel[i,] <- syscount[i,]/apply(syscount, 2, sum)
}

rownames(sysrel) <- rownames(syscount)
colnames(sysrel) <- colnames(syscount)
sysrel <- round(sysrel, digits=2)

syscount <- syscount[,-1]
# Number of legislative electoral systems by decade:
syscount

## Graph
par(mar=c(2.1,2.1,1.1,0.1))
barplot(syscount,
		ylab=list("Number of Elections", cex=1.3),
		ylim=c(0,160),
		beside=T,
		col=c("grey20", "grey50", "grey80"),
		legend = c("Majoritarian", "Proportional", "Mixed"),
		args.legend=list(x="top", cex=1.2)
)

#############################################################
### Figure 4
## Data Prep
# map for 2006-2011
unique(ccode[year>2006 & !is.na(legislative_type)], legislative_type[year>2006 & !is.na(legislative_type)])
elecsys11 <- table(legislative_type[year>2006 & !is.na(legislative_type)], ccode[year>2006 & !is.na(legislative_type)])
elecsys11[elecsys11>1] <- 1 # transform all counts > 1 to 1
apply(elecsys11, 2, sum) # check that colsum is never greater > 1 & never < 1

rownames(elecsys11) <- c("Maj", "PR", "Mix")

# map for 1996-2001
elecsys01 <- table(legislative_type[year>1996 & year <= 2001 & !is.na(legislative_type)], ccode[year>1996 & year <= 2001 & !is.na(legislative_type)])
elecsys01[elecsys01>1] <- 1 # transform all counts > 1 to 1
apply(elecsys01, 2, sum) # check that colsum is never greater > 1 & never < 1

rownames(elecsys01) <- c("Maj", "PR", "Mix")

# map for 1986-1991
elecsys91 <- table(legislative_type[year>1986 & year <= 1991 & !is.na(legislative_type)], ccode[year>1986 & year <= 1991 & !is.na(legislative_type)])
elecsys91[elecsys91>1] <- 1 # transform all counts > 1 to 1
apply(elecsys91, 2, sum) # check that colsum is never greater > 1 & never < 1

rownames(elecsys91) <- c("Maj", "PR", "Mix")

# map for 1976-1981
elecsys81 <- table(legislative_type[year>1976 & year <= 1981 & !is.na(legislative_type)], ccode[year>1976 & year <= 1981 & !is.na(legislative_type)])
elecsys81[elecsys81>1] <- 1 # transform all counts > 1 to 1
apply(elecsys81, 2, sum) # check that colsum is never greater > 1 & never < 1

rownames(elecsys81) <- c("Maj", "PR", "Mix")

# map for 1966-1971
elecsys71 <- table(legislative_type[year>1966 & year <= 1971 & !is.na(legislative_type)], ccode[year>1966 & year <= 1971 & !is.na(legislative_type)])
elecsys71[elecsys71>1] <- 1 # transform all counts > 1 to 1
apply(elecsys71, 2, sum) # check that colsum is never greater > 1 & never < 1

rownames(elecsys71) <- c("Maj", "PR", "Mix")

# map for 1966-1971
elecsys61 <- table(legislative_type[year>1956 & year <= 1961 & !is.na(legislative_type)], ccode[year>1956 & year <= 1961 & !is.na(legislative_type)])
elecsys61[elecsys61>1] <- 1 # transform all counts > 1 to 1
apply(elecsys61, 2, sum) # check that colsum is never greater > 1 & never < 1

rownames(elecsys61) <- c("Maj", "PR", "Mix")


# map world
library(cshapes)
world <- cshp()

#world@data <- world@data[order(world$COWCODE),]

world08 <- world[world$COWSYEAR<=2008 & world$COWEYEAR>=2008,]
world08 <- world08[world08$FEATUREID!=234,]	# drop Serbia with Kosovo

world01 <- world[world$COWSYEAR<=2001 & world$COWEYEAR>=2001,]

world91 <- world[world$COWSYEAR<=1991 & world$COWEYEAR>=1991,]
world91$COWCODE[duplicated(world91$COWCODE)] # Three Russia Polygons
world91@data[world91$COWCODE==365,]
world91 <- world91[world91$FEATUREID!=192,]	# drop SU 
world91 <- world91[world91$FEATUREID!=232,]	# drop SU 2

world81 <- world[world$COWSYEAR<=1981 & world$COWEYEAR>=1981,]

world71 <- world[world$COWSYEAR<=1971 & world$COWEYEAR>=1971,]
world71$COWCODE[duplicated(world71$COWCODE)] # Two Pakistan Polygons
world71@data[world71$COWCODE==770,]
world71 <- world71[world71$FEATUREID!=204,]	# drop Pakistan with Bangladesh

world61 <- world[world$COWSYEAR<=1961 & world$COWEYEAR>=1961,]
world61$COWCODE[duplicated(world61$COWCODE)] # Two Polygons for Egypt, Cameroon, and Nigeria
world61@data[world61$COWCODE==651,]
world61 <- world61[world61$FEATUREID!=199,]	# drop Egypt/United Arab Republic
world61@data[world61$COWCODE==471,]
world61 <- world61[world61$FEATUREID!=215,]	# drop first Cameroon
world61@data[world61$COWCODE==475,]
world61 <- world61[world61$FEATUREID!=216,]	# drop first Nigeria

## Graph
# Prepare map

layout(matrix(c(1,1,2,2,3,3), 3, 2, byrow=T), heights=c(3,3,3))
par(mar=c(1,0.1, 0.1, 0.1))
op <- par(no.readonly=TRUE) 

# 2011 map
plot(world08, lwd=1)

maj <- as.numeric(colnames(elecsys11)[elecsys11[1,]==1])
pr <- as.numeric(colnames(elecsys11)[elecsys11[2,]==1])
mix <- as.numeric(colnames(elecsys11)[elecsys11[3,]==1])

plot(world08[world08$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(world08[match(maj, world08$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(world08[world08$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(world08[match(pr, world08$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(world08[world08$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(world08[match(mix, world08$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("2011", 1, cex=1)

# 2001 map
par(mar=c(1,0.1, 0.1, 0.1))
plot(world01, lwd=1)

maj <- as.numeric(colnames(elecsys01)[elecsys01[1,]==1])
pr <- as.numeric(colnames(elecsys01)[elecsys01[2,]==1])
mix <- as.numeric(colnames(elecsys01)[elecsys01[3,]==1])

plot(world01[world01$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(world01[match(maj, world01$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(world01[world01$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(world01[match(pr, world01$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(world01[world01$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(world01[match(mix, world01$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("2001", 1, cex=1)

# 1991 map
par(mar=c(1,0.1, 0.1, 0.1))
plot(world91, lwd=1)

maj <- as.numeric(colnames(elecsys91)[elecsys91[1,]==1])
pr <- as.numeric(colnames(elecsys91)[elecsys91[2,]==1])
mix <- as.numeric(colnames(elecsys91)[elecsys91[3,]==1])

plot(world91[world91$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(world91[match(maj, world91$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(world91[world91$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(world91[match(pr, world91$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(world91[world91$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(world91[match(mix, world91$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1991", 1, cex=1)

# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.575, 1.25, legend=c("Majoritarian", "PR", "Mixed", "Autocratic"),
		fill=c("grey30", "grey90", "grey60", "white"),
		#angle=c(45, 135, 90, 0),
		#density=c(20, 20, 20, 0),
		bty="o",
		box.col="black",
		cex=.8,
		ncol=1
)




layout(matrix(c(1,1,2,2,3,3), 3, 2, byrow=T), heights=c(3,3,3))
par(mar=c(1,0.1, 0.1, 0.1))
op <- par(no.readonly=TRUE) 

# 1981 map
par(mar=c(1,0.1, 0.1, 0.1))
plot(world81, lwd=1)

maj <- as.numeric(colnames(elecsys81)[elecsys81[1,]==1])
pr <- as.numeric(colnames(elecsys81)[elecsys81[2,]==1])
mix <- as.numeric(colnames(elecsys81)[elecsys81[3,]==1])

plot(world81[world81$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(world81[match(maj, world81$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(world81[world81$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(world81[match(pr, world81$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(world81[world81$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(world81[match(mix, world81$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1981", 1, cex=1)

# 1971 map
par(mar=c(1,0.1, 0.1, 0.1))
plot(world71, lwd=1)

maj <- as.numeric(colnames(elecsys71)[elecsys71[1,]==1])
pr <- as.numeric(colnames(elecsys71)[elecsys71[2,]==1])
mix <- as.numeric(colnames(elecsys71)[elecsys71[3,]==1])

plot(world71[world71$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(world71[match(maj, world71$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(world71[world71$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(world71[match(pr, world71$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(world71[world71$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(world71[match(mix, world71$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1971", 1, cex=1)

# 1961 map
par(mar=c(1,0.1, 0.1, 0.1))
plot(world61, lwd=1)

maj <- as.numeric(colnames(elecsys61)[elecsys61[1,]==1])
pr <- as.numeric(colnames(elecsys61)[elecsys61[2,]==1])
mix <- as.numeric(colnames(elecsys61)[elecsys61[3,]==1])

plot(world61[world61$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(world61[match(maj, world61$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(world61[world61$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(world61[match(pr, world61$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(world61[world61$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(world61[match(mix, world61$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1961", 1, cex=1)


# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.575, 1.25, legend=c("Majoritarian", "PR", "Mixed", "Autocratic"),
		fill=c("grey30", "grey90", "grey60", "white"),
		#angle=c(45, 135, 90, 0),
		#density=c(20, 20, 20, 0),
		bty="o",
		box.col="black",
		cex=.8,
		ncol=1
)


#############################################################
### Figure 5
## Data Prep
## electoral rules for 2006-2011 (majoritarian)
mrules <- data.frame(ccode[year>=2005 & legislative_type==1 & !is.na(legislative_type)], tier1_formula[year>=2005 & legislative_type==1 & !is.na(legislative_type)])
names(mrules) <- c("ccode", "elecrules")
mrules <- unique(mrules) # only unique combinations
mrules11 <- table(mrules$elecrules)	
mrules11 <- mrules11[-dim(mrules11)] # kick Madagascar with Hare quota
names(mrules11) <- c("SMDP\n", "TRS \n Maj.-Plu.", "TRS \n Maj.-Maj.", "AV\n", "mBC\n", "BV\n", "SNTV\n")
# reorder by Plurality/Majority - most common to least common
mrules11 <- mrules11[c(1,6,2,5,7,3,4)] 


## electoral rules for 2006-2011 (proportional)	
prrules <- data.frame(ccode[year>=2005 & legislative_type==2 & !is.na(legislative_type)], tier1_formula[year>=2005 & legislative_type==2 & !is.na(legislative_type)])
names(prrules) <- c("ccode", "elecrules")
prrules <- unique(prrules) # only unique combinations
prrules11 <- table(prrules$elecrules)
# combine hare
prrules11[1] <- prrules11[1] + prrules11[2] + prrules11[3] # add
prrules11 <- prrules11[c(1,4:10)]
# combine droop
prrules11[3] <- prrules11[3] + prrules11[4]
prrules11 <- prrules11[c(1:3,5:8)]
#names
names(prrules11) <- c("Hare\n",  "Hag.-\n Bisch.", "Droop\n", "D'Hondt\n", "Sainte-\n Lague", "Mod.\n S.-L.", "STV\n")
# order by quota/divisor - most common to least common
prrules11 <- prrules11[c(1:4, 6, 5, 7)]


## electoral rules for 2006-2011 (mixed)	
mixrules <- data.frame(ccode[year>=2005 & !is.na(mixed_type)], mixed_type[year>=2005 & !is.na(mixed_type)])
names(mixrules) <- c("ccode", "elecrules")
mixrules <- unique(mixrules) # only unique combinations
mixrules11 <- table(mixrules$elecrules)
names(mixrules11) <- c("Coexistence", "Supposition", "Correction", "Conditional")
# order by quota/divisor - most common to least common
mixrules11 <- mixrules11[c(2,1,3:4)]
sum(mixrules11[1:2])/sum(mixrules11)*100


### Figures in the text
# Proportion of PR rules from 2005-2011
prrules11

# Proportion of majoritarian rules from 2005-2011
mrules11

# Proportion of mixed rules from 2005-2011
mixrules11

# Proportion of PR rules that are divisor based
round(sum(prrules11[3:5])/sum(prrules11[1:6]), digits=2)*100

# Proportion of independent and dependent mixed systems
sum(mixrules11[1:2])/sum(mixrules11)*100 # independent 
sum(mixrules11[3:4])/sum(mixrules11)*100 # dependent

# Proportion of dependent mixed systems in the 1990s 
round(length(unique(ccode[mixed_type>3 & year>=1991 & year<2001 & !is.na(mixed_type)]))
	/length(unique(ccode[year>=1991 & year<2001 & !is.na(mixed_type)])),digits=2)*100

# Proportion of PR rules in mixed systems in the 2000s 
mixdh2000 <- length(ccode[tier2_formula==25 & year>2000 & !is.na(mixed_type)])
mixha2000 <- length(ccode[tier2_formula==13 & year>2000 & !is.na(mixed_type)])
mix2000 <- length(ccode[year>2000 & !is.na(mixed_type)])
# Proportion d'Hondt in mixed systems
mixdh2000/mix2000
# Proportion Hare w/ Largest Remainder in mixed systems
mixha2000/mix2000

## Graph
layout(matrix(c(1,2,3), 3, 1, byrow=T), heights=c(5,5,5))
par(mar=c(2.1,4.1,4.1,2.1))

barplot(mrules11,
		ylab=list("Number of States", cex=1.3),
		ylim=c(0,30),
		main="Majoritarian Systems",
		cex.names=1,
		cex.axis=.8,
		space=.75
)

barplot(prrules11,
		ylab=list("Number of States", cex=1.3),
		ylim=c(0,40),
		main="Proportional Systems",
		cex.names=1,
		cex.axis=.8,
		space=.75
)

barplot(mixrules11,
		ylab=list("Number of States", cex=1.3),
		ylim=c(0,12),
		main="Mixed Systems",
		cex.names=1,
		cex.axis=.8,
		space=.75
)


#############################################################
### Figure 6
## Data Prep
enep[enep<0] <- NA
enpp[enpp<0] <- NA

enepflag <- ifelse(is.na(enpp), 1, 0) 
enppflag <- ifelse(is.na(enep), 1, 0)

enepdecsys <- matrix(0, max(legislative_type, na.rm=T), 7)
enppdecsys <- matrix(0, max(legislative_type, na.rm=T), 7)

for(i in 1:max(legislative_type, na.rm=T)){
	for(j in 1:max(decade)-1){
		enepdecsys[i,j] <- mean(enep[legislative_type==i & decade==j & enepflag!=1], na.rm=T)
		enppdecsys[i,j] <- mean(enpp[legislative_type==i & decade==j & enppflag!=1], na.rm=T)
	}
}

rownames(enepdecsys) <- c("Majoritarian", "Proportional", "Mixed")
colnames(enepdecsys) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")
rownames(enppdecsys) <- c("Majoritarian", "Proportional", "Mixed")
colnames(enppdecsys) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")

enepdecsys <- enepdecsys[,-1]# kick 1940s
enppdecsys <- enppdecsys[,-1] # kick 1940s


### compare over stable set of democracies (West, India)
stable <- c(2,20,90,200:225,255,305,325,375:395,740,750,900,920)
enepdecsys_s <- matrix(0, max(legislative_type, na.rm=T), 7)
enppdecsys_s <- matrix(0, max(legislative_type, na.rm=T), 7)

for(i in 1:max(legislative_type, na.rm=T)){
	for(j in 1:max(decade)-1){
		enepdecsys_s[i,j] <- mean(enep[legislative_type==i & decade==j & enepflag!=1 & ccode%in%stable], na.rm=T)
		enppdecsys_s[i,j] <- mean(enpp[legislative_type==i & decade==j & enppflag!=1 & ccode%in%stable], na.rm=T)
	}
}

rownames(enepdecsys_s) <- c("Majoritarian", "Proportional", "Mixed")
colnames(enepdecsys_s) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")
rownames(enppdecsys_s) <- c("Majoritarian", "Proportional", "Mixed")
colnames(enppdecsys_s) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")

enepdecsys_s <- enepdecsys_s[,-1]# kick 1940s
enppdecsys_s <- enppdecsys_s[,-1] # kick 1940s

### compare over unstable set of democracies
unstable <- unique(ccode[!is.element(ccode, stable)])
enepdecsys_us <- matrix(0, max(legislative_type, na.rm=T), 7)
enppdecsys_us <- matrix(0, max(legislative_type, na.rm=T), 7)

for(i in 1:max(legislative_type, na.rm=T)){
	for(j in 1:max(decade)-1){
		enepdecsys_us[i,j] <- mean(enep[legislative_type==i & decade==j & enepflag!=1 & ccode%in%unstable], na.rm=T)
		enppdecsys_us[i,j] <- mean(enpp[legislative_type==i & decade==j & enppflag!=1 & ccode%in%unstable], na.rm=T)
	}
}

rownames(enepdecsys_us) <- c("Majoritarian", "Proportional", "Mixed")
colnames(enepdecsys_us) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")
rownames(enppdecsys_us) <- c("Majoritarian", "Proportional", "Mixed")
colnames(enppdecsys_us) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")

enepdecsys_us <- enepdecsys_us[,-1]# kick 1940s
enppdecsys_us <- enppdecsys_us[,-1] # kick 1940s

## Figure 6 numbers
# ENEP in established democracies
enepdecsys_s
# ENPP in established democracies
enepdecsys_s
# ENEP in non-established democracies
enepdecsys_us
# ENPP in non-established democracies
enepdecsys_us

## Graph
par(mfrow=c(2,2))
par(mar=c(3.1, 4.1, 2.1, 2.1))
op <- par(no.readonly=TRUE)

for(i in 1:2){
	#ENEP established
	plot(c(enepdecsys_s[i,]), c(1:length(colnames(enepdecsys_s))),
			xlim = c(2, 6),
			xlab="", ylab="",
			type = "p", axes = F, pch = 19, col="black")
	
	if(i==1) title(main="Established Democracies")
	
	#ENPP established
	points(c(enppdecsys_s[i,]), c(1:length(colnames(enppdecsys_s))),
			type = "p", pch = 17, col="black")
	
	
	abline(h = c(1:length(colnames(enepdecsys))), lty = "dotted") # draw lines
	box(bty = "l")
	axis(1, at=seq(1,7, by=1), labels = seq(1:7), 
			cex = 1, las = 1, tick = T, cex.axis = 0.8,
			line = 0, mgp = c(2,.5,0)) #mgp moves label closer to tick marks
	axis(2, at = c(1:length(colnames(enepdecsys))), labels = colnames(enepdecsys), tick = T, las  = 1, 
			line =0, cex.axis = 1)  
	mtext(rownames(enepdecsys)[i], 2, font = 2, cex = 1, line = 4) #create elec. system labels
	#####################################################################################################################
	#ENEP non-established 
	plot(c(enepdecsys_us[i,]), c(1:length(colnames(enepdecsys_us))),
			xlim = c(2, 6),
			xlab="", ylab="",
			type = "p", axes = F, pch = 19, col="black")
	
	if(i==1) title(main="Non-Established Democracies")
	#ENPP non-established
	points(c(enppdecsys_us[i,]), c(1:length(colnames(enppdecsys_us))),
			type = "p", pch = 17, col="black")
	
	abline(h = c(1:length(colnames(enepdecsys))), lty = "dotted") # draw lines
	box(bty = "l")
	axis(1, at=seq(1,7, by=1), labels = seq(1:7), 
			cex = 1, las = 1, tick = T, cex.axis = 0.8,
			line = 0, mgp = c(2,.5,0)) #mgp moves label closer to tick marks
	axis(2, at = c(1:length(colnames(enepdecsys))), labels = colnames(enepdecsys), tick = T, las  = 1, 
			line =0, cex.axis = 1)  
	mtext(rownames(enepdecsys)[i], 2, font = 2, cex = 1, line = 4) #create elec. system labels
	
}


# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.7, 1.03, legend=c("Effective Number of Electoral Parties", "Effective Number of Parliamentary Parties"),
		pch=c(19,17),
		col="black",
		bty="n",
		#box.col="black",
		cex=.8,
		ncol=1
)

#############################################################
### Figure 7
## Data Prep
sysreg <- table(legislative_type[year>2000 & year < 2011], region3[year>2000 & year < 2011])
rownames(sysreg) <- c("Majoritarian",  "PR", "Mixed")
colnames(sysreg) <- c("SSA", "Asia", "West", "EEU", "Pacific", "MENA", "LAm &\n Car")

relsysreg <- sysreg
relsysreg[1,] <- sysreg[1,]/apply(sysreg,2,sum)
relsysreg[2,] <- sysreg[2,]/apply(sysreg,2,sum)
relsysreg[3,] <- sysreg[3,]/apply(sysreg,2,sum)

## Numbers for figure 7 
relsysreg

## Graph
par(mar=c(9, 4, 2, 2)) # set margins - South, West, North, East
op <- par(no.readonly=TRUE) #   
barplot(relsysreg,
		ylab=list("Proportion of Elections", cex=1.3),
		ylim=c(0,1),
		col=c("grey20", "grey50", "grey80"),
)


par(xpd=TRUE)  # Do not clip legend to the drawing area
lambda=0.15
legend((par("usr")[2]-par("usr")[1])/2, # x-coordinate legend box
		par("usr")[3]-lambda, # y-coordinate legend box
		c("Majoritarian", "PR", "Mixed"),
		fill=c("grey20", "grey50", "grey80"),
		xjust=0.5, # justified to the x-coordinate: middle
		yjust=1 # justified to the y-coordinate: down
)
par(op)


#############################################################
### Figure 8
## Data Prep
presysdec <- matrix(0, max(preselecrule, na.rm=T), max(decade)-1)

for(i in 1:5){
	for(j in 1:max(decade)-1){
		presysdec[i,j] <- length(ccode[preselecrule==i & decade==j & presidential==1]) 
	}
}


rownames(presysdec) <- c("Plurality", "Absolute_Maj.", "Qualfied_Maj.", "Electoral_College", "AV")
colnames(presysdec) <- c("1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s")

relpresysdec <- presysdec
for(i in 1:dim(presysdec)[1]){
	relpresysdec[i,] <- presysdec[i,]/apply(presysdec, 2,sum)
}

relpresysdec <- relpresysdec[,-1] 

## Numbers for Figure 8 as well as in the text
relpresysdec 

## Graph
par(mfrow=c(1,1))
par(mar=c(9, 5, 2, 2)) # set margins - South, West, North, East
op <- par(no.readonly=TRUE) #   
barplot(relpresysdec,
		ylab=list("Proportion of Elections", cex=1.3),
		ylim=c(0,1),
		col=c("grey90", "grey70", "grey50", "grey30", "black"),
)


par(xpd=TRUE)  # Do not clip legend to the drawing area
lambda=0.15
legend((par("usr")[2]-par("usr")[1])/2, # x-coordinate legend box
		par("usr")[3]-lambda, # y-coordinate legend box
		c("Plurality", "Absolute Majority", "Qualified Majority", "Electoral College", "Alternative Vote"),
		fill=c("grey90", "grey70", "grey50", "grey30", "black"),
		xjust=0.5, # justified to the x-coordinate: middle
		yjust=1 # justified to the y-coordinate: right
)
par(op)

#############################################################
### Figure 9
## Data Prep
presysenpc90 <- data.frame(enpres[decade==6 & presidential==1], preselecrule[decade==6 & presidential==1], decade[decade==6 & presidential==1])
presysenpc00 <- data.frame(enpres[decade==7 & presidential==1], preselecrule[decade==7 & presidential==1], decade[decade==7 & presidential==1])
presysenpc90$decade <- "1990s"
presysenpc00$decade <- "2000s"
names(presysenpc90) <- c("enpres", "type", "decade")
names(presysenpc00) <- c("enpres", "type", "decade")

presysenpc <- rbind(presysenpc90, presysenpc00)
presysenpc <- presysenpc[presysenpc$type <= 4,]

## Graph
op <- par(no.readonly=TRUE) #   	
boxplot(enpres~decade*type,
		data=presysenpc,
		bty = "l",
		boxwex=0.6,
		outline=F,
		range=1.5,
		col=c("grey20", "grey80"),
		ylab= list("Effective Number of Presidential Candidates", cex=1.3),
		names=F
)

wid <- (par("usr")[2] - par("usr")[1])/9 # x coordinate end - x coordinate y divided by number equally space ticks
lambda = 0.1 # small indentation before every tick
mtext(c("Plurality", "Absolute\nMajority", "Qualified\nMajority", "Electoral\nCollege"), side=1, line=2,
		at=c(par("usr")[1] + wid - lambda, par("usr")[1] + wid*3 - lambda, par("usr")[1] + wid*5 - lambda, par("usr")[1] + wid*7 - lambda),
		adj=0)

par(xpd=TRUE)  # Do not clip legend to the drawing area
legend((par("usr")[1]), # x-coordinate legend box
		par("usr")[4], # y-coordinate legend box
		c("1990s", "2000s"),
		fill=c("grey20", "grey80"),
		xjust=0, # justified to the x-coordinate: middle
		yjust=1 # justified to the y-coordinate: down
)
par(op)

#############################################################
########################## Appendix #########################
#############################################################

### Figure 10
## Data Prep
# Prepare map
layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow=T), heights=c(3,3,3))
par(mar=c(1,0.1, 0.1, 0.1))
op <- par(no.readonly=TRUE) 

## Graph
# 2011 map Europe
par(mar=c(1,0.1, 0.1, 0.1))

world08$COWCODE[world08$COWCODE == 640] <- 399 # include Europe in Turkey
euro08 <- world08[world08$COWCODE >=200 & world08$COWCODE <=400 & world08$COWCODE!=365,]
euro08$COWCODE[euro08$COWCODE == 399] <- 640	# return to its original COWCODE

plot(euro08, lwd=1)

maj <- as.numeric(colnames(elecsys11)[elecsys11[1,]==1])
pr <- as.numeric(colnames(elecsys11)[elecsys11[2,]==1])
mix <- as.numeric(colnames(elecsys11)[elecsys11[3,]==1])

plot(euro08[euro08$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(euro08[match(maj, euro08$COWCODE),], density=20, angle=45, lwd=0.08,  add=T) # add maj stripes
plot(euro08[euro08$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(euro08[match(pr, euro08$COWCODE),], density=20, angle=135, lwd=0.08,  add=T) # add pr stripes
plot(euro08[euro08$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(euro08[match(mix, euro08$COWCODE),], density=20, angle=90, lwd=0.08,  add=T) # add mix stripes

mtext("2011", 1, cex=1)


# 2001 map Europe
par(mar=c(1,0.1, 0.1, 0.1))

world01$COWCODE[world01$COWCODE == 640] <- 399 # include Turkey into Europe
euro01 <- world01[world01$COWCODE >=200 & world01$COWCODE <=400 & world01$COWCODE!=365,]
euro01$COWCODE[euro01$COWCODE == 399] <- 640	# return to its original COWCODE	

plot(euro01, lwd=1)

maj <- as.numeric(colnames(elecsys01)[elecsys01[1,]==1])
pr <- as.numeric(colnames(elecsys01)[elecsys01[2,]==1])
mix <- as.numeric(colnames(elecsys01)[elecsys01[3,]==1])

plot(euro01[euro01$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(euro01[match(maj, euro01$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(euro01[euro01$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(euro01[match(pr, euro01$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(euro01[euro01$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(euro01[match(mix, euro01$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("2001", 1, cex=1)


# 1991 map Europe
par(mar=c(1,0.1, 0.1, 0.1))
world91$COWCODE[world91$COWCODE == 640] <- 399 # include Europe in Turkey
euro91 <- world91[world91$COWCODE >=200 & world91$COWCODE <=400 & world91$COWCODE!=365,]
euro91$COWCODE[euro91$COWCODE == 399] <- 640	# return to its original COWCODE	
plot(euro91, lwd=1)

maj <- as.numeric(colnames(elecsys91)[elecsys91[1,]==1])
pr <- as.numeric(colnames(elecsys91)[elecsys91[2,]==1])
mix <- as.numeric(colnames(elecsys91)[elecsys91[3,]==1])

plot(euro91[euro91$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(euro91[match(maj, euro91$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(euro91[euro91$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(euro91[match(pr, euro91$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(euro91[euro91$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(euro91[match(mix, euro91$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1991", 1, cex=1)

# 1981 map Europe
par(mar=c(1,0.1, 0.1, 0.1))
world81$COWCODE[world81$COWCODE == 640] <- 399 # include Europe in Turkey
euro81 <- world81[world81$COWCODE >=200 & world81$COWCODE <=400 & world81$COWCODE!=365,]
euro81$COWCODE[euro81$COWCODE == 399] <- 640	# return to its original COWCODE	
plot(euro81, lwd=1)

maj <- as.numeric(colnames(elecsys81)[elecsys81[1,]==1])
pr <- as.numeric(colnames(elecsys81)[elecsys81[2,]==1])
mix <- as.numeric(colnames(elecsys81)[elecsys81[3,]==1])

plot(euro81[euro81$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(euro81[match(maj, euro81$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(euro81[euro81$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(euro81[match(pr, euro81$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(euro81[euro81$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(euro81[match(mix, euro81$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1981", 1, cex=1)

# 1971 map Europe
par(mar=c(1,0.1, 0.1, 0.1))
world71$COWCODE[world71$COWCODE == 640] <- 399 # include Europe in Turkey
euro71 <- world71[world71$COWCODE >=200 & world71$COWCODE <=400 & world71$COWCODE!=365,]
euro71$COWCODE[euro71$COWCODE == 399] <- 640	# return to its original COWCODE	
plot(euro71, lwd=1)

maj <- as.numeric(colnames(elecsys71)[elecsys71[1,]==1])
pr <- as.numeric(colnames(elecsys71)[elecsys71[2,]==1])
mix <- as.numeric(colnames(elecsys71)[elecsys71[3,]==1])

plot(euro71[euro71$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(euro71[match(maj, euro71$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(euro71[euro71$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(euro71[match(pr, euro71$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(euro71[euro71$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(euro71[match(mix, euro71$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1971", 1, cex=1)

# 1961 map Europe
par(mar=c(1,0.1, 0.1, 0.1))
world61$COWCODE[world61$COWCODE == 640] <- 399 # include Europe in Turkey
euro61 <- world61[world61$COWCODE >=200 & world61$COWCODE <=400 & world61$COWCODE!=365,]
euro61$COWCODE[euro61$COWCODE == 399] <- 640	# return to its original COWCODE	
plot(euro61, lwd=1)

maj <- as.numeric(colnames(elecsys61)[elecsys61[1,]==1])
pr <- as.numeric(colnames(elecsys61)[elecsys61[2,]==1])
mix <- as.numeric(colnames(elecsys61)[elecsys61[3,]==1])

plot(euro61[euro61$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(euro61[match(maj, euro61$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(euro61[euro61$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(euro61[match(pr, euro61$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(euro61[euro61$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(euro61[match(mix, euro61$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1961", 1, cex=1)

# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.88, 1.15, legend=c("Majoritarian", "PR", "Mixed", "Autocratic"),
		fill=c("grey30", "grey90", "grey60", "white"),
		#angle=c(45, 135, 90, 0),
		#density=c(20, 20, 20, 0),
		bty="o",
		box.col="black",
		cex=.8,
		ncol=1
)

#############################################################
### Figure 11
## Data Prep
## South America
# Prepare map
layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow=T), heights=c(3,3,3))
par(mar=c(1,0.1, 0.1, 0.1))
op <- par(no.readonly=TRUE) 

## Graph
# 2011 map South America
par(mar=c(1,0.1, 0.1, 0.1))

sam08 <- world08[world08$COWCODE >=40 & world08$COWCODE <=199,]


plot(sam08, lwd=1)

maj <- as.numeric(colnames(elecsys11)[elecsys11[1,]==1])
pr <- as.numeric(colnames(elecsys11)[elecsys11[2,]==1])
mix <- as.numeric(colnames(elecsys11)[elecsys11[3,]==1])

plot(sam08[sam08$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(sam08[match(maj, sam08$COWCODE),], density=20, angle=45, lwd=0.08,  add=T) # add maj stripes
plot(sam08[sam08$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(sam08[match(pr, sam08$COWCODE),], density=20, angle=135, lwd=0.08,  add=T) # add pr stripes
plot(sam08[sam08$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(sam08[match(mix, sam08$COWCODE),], density=20, angle=90, lwd=0.08,  add=T) # add mix stripes

mtext("2011", 1, cex=1)


# 2001 map South America
par(mar=c(1,0.1, 0.1, 0.1))
sam01 <- world01[world01$COWCODE >=40 & world01$COWCODE <=199,]
plot(sam01, lwd=1)

maj <- as.numeric(colnames(elecsys01)[elecsys01[1,]==1])
pr <- as.numeric(colnames(elecsys01)[elecsys01[2,]==1])
mix <- as.numeric(colnames(elecsys01)[elecsys01[3,]==1])

plot(sam01[sam01$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(sam01[match(maj, sam01$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(sam01[sam01$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(sam01[match(pr, sam01$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(sam01[sam01$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(sam01[match(mix, sam01$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("2001", 1, cex=1)


# 1991 map South America
par(mar=c(1,0.1, 0.1, 0.1))
sam91 <- world91[world91$COWCODE >=40 & world91$COWCODE <=199,]
plot(sam91, lwd=1)

maj <- as.numeric(colnames(elecsys91)[elecsys91[1,]==1])
pr <- as.numeric(colnames(elecsys91)[elecsys91[2,]==1])
mix <- as.numeric(colnames(elecsys91)[elecsys91[3,]==1])

plot(sam91[sam91$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(sam91[match(maj, sam91$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(sam91[sam91$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(sam91[match(pr, sam91$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(sam91[sam91$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(sam91[match(mix, sam91$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1991", 1, cex=1)

# 1981 map South America
par(mar=c(1,0.1, 0.1, 0.1))
sam81 <- world81[world81$COWCODE >=40 & world81$COWCODE <=199,]
plot(sam81, lwd=1)

maj <- as.numeric(colnames(elecsys81)[elecsys81[1,]==1])
pr <- as.numeric(colnames(elecsys81)[elecsys81[2,]==1])
mix <- as.numeric(colnames(elecsys81)[elecsys81[3,]==1])

plot(sam81[sam81$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(sam81[match(maj, sam81$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(sam81[sam81$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(sam81[match(pr, sam81$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(sam81[sam81$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(sam81[match(mix, sam81$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1981", 1, cex=1)

# 1971 map South America
par(mar=c(1,0.1, 0.1, 0.1))
sam71 <- world71[world71$COWCODE >=40 & world71$COWCODE <=199,]
plot(sam71, lwd=1)

maj <- as.numeric(colnames(elecsys71)[elecsys71[1,]==1])
pr <- as.numeric(colnames(elecsys71)[elecsys71[2,]==1])
mix <- as.numeric(colnames(elecsys71)[elecsys71[3,]==1])

plot(sam71[sam71$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(sam71[match(maj, sam71$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(sam71[sam71$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(sam71[match(pr, sam71$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(sam71[sam71$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(sam71[match(mix, sam71$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1971", 1, cex=1)

# 1961 map South America
par(mar=c(1,0.1, 0.1, 0.1))
sam61 <- world61[world61$COWCODE >=40 & world61$COWCODE <=199,]
plot(sam61, lwd=1)

maj <- as.numeric(colnames(elecsys61)[elecsys61[1,]==1])
pr <- as.numeric(colnames(elecsys61)[elecsys61[2,]==1])
mix <- as.numeric(colnames(elecsys61)[elecsys61[3,]==1])

plot(sam61[sam61$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(sam61[match(maj, sam61$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(sam61[sam61$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(sam61[match(pr, sam61$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(sam61[sam61$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(sam61[match(mix, sam61$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1961", 1, cex=1)

# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.88, 1.15, legend=c("Majoritarian", "PR", "Mixed", "Autocratic"),
		fill=c("grey30", "grey90", "grey60", "white"),
		#angle=c(45, 135, 90, 0),
		#density=c(20, 20, 20, 0),
		bty="o",
		box.col="black",
		cex=.8,
		ncol=1
)


#############################################################
### Figure 11
## Data Prep
## Southeast Asia
# Prepare map
layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow=T), heights=c(3,3,3))
par(mar=c(1,0.1, 0.1, 0.1))
op <- par(no.readonly=TRUE) 

## Graph
# 2011 map Southeast Asia
par(mar=c(1,0.1, 0.1, 0.1))

seasia08 <- world08[world08$COWCODE >=750 & world08$COWCODE <=860,]


plot(seasia08, lwd=1)

maj <- as.numeric(colnames(elecsys11)[elecsys11[1,]==1])
pr <- as.numeric(colnames(elecsys11)[elecsys11[2,]==1])
mix <- as.numeric(colnames(elecsys11)[elecsys11[3,]==1])

plot(seasia08[seasia08$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(seasia08[match(maj, seasia08$COWCODE),], density=20, angle=45, lwd=0.08,  add=T) # add maj stripes
plot(seasia08[seasia08$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(seasia08[match(pr, seasia08$COWCODE),], density=20, angle=135, lwd=0.08,  add=T) # add pr stripes
plot(seasia08[seasia08$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(seasia08[match(mix, seasia08$COWCODE),], density=20, angle=90, lwd=0.08,  add=T) # add mix stripes

mtext("2011", 1, cex=1)


# 2001 map Southeast Asia
par(mar=c(1,0.1, 0.1, 0.1))
seasia01 <- world01[world01$COWCODE >=750 & world01$COWCODE <=860,]
plot(seasia01, lwd=1)

maj <- as.numeric(colnames(elecsys01)[elecsys01[1,]==1])
pr <- as.numeric(colnames(elecsys01)[elecsys01[2,]==1])
mix <- as.numeric(colnames(elecsys01)[elecsys01[3,]==1])

plot(seasia01[seasia01$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(seasia01[match(maj, seasia01$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(seasia01[seasia01$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(seasia01[match(pr, seasia01$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(seasia01[seasia01$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(seasia01[match(mix, seasia01$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("2001", 1, cex=1)


# 1991 map Southeast Asia
par(mar=c(1,0.1, 0.1, 0.1))
seasia91 <- world91[world91$COWCODE >=750 & world91$COWCODE <=860,]
plot(seasia91, lwd=1)

maj <- as.numeric(colnames(elecsys91)[elecsys91[1,]==1])
pr <- as.numeric(colnames(elecsys91)[elecsys91[2,]==1])
mix <- as.numeric(colnames(elecsys91)[elecsys91[3,]==1])

plot(seasia91[seasia91$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(seasia91[match(maj, seasia91$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(seasia91[seasia91$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(seasia91[match(pr, seasia91$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(seasia91[seasia91$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(seasia91[match(mix, seasia91$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1991", 1, cex=1)

# 1981 map Southeast Asia
par(mar=c(1,0.1, 0.1, 0.1))
seasia81 <- world81[world81$COWCODE >=750 & world81$COWCODE <=860,]
plot(seasia81, lwd=1)

maj <- as.numeric(colnames(elecsys81)[elecsys81[1,]==1])
pr <- as.numeric(colnames(elecsys81)[elecsys81[2,]==1])
mix <- as.numeric(colnames(elecsys81)[elecsys81[3,]==1])

plot(seasia81[seasia81$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(seasia81[match(maj, seasia81$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(seasia81[seasia81$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(seasia81[match(pr, seasia81$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(seasia81[seasia81$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(seasia81[match(mix, seasia81$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1981", 1, cex=1)

# 1971 map Southeast Asia
par(mar=c(1,0.1, 0.1, 0.1))
seasia71 <- world71[world71$COWCODE >=750 & world71$COWCODE <=860,]
plot(seasia71, lwd=1)

maj <- as.numeric(colnames(elecsys71)[elecsys71[1,]==1])
pr <- as.numeric(colnames(elecsys71)[elecsys71[2,]==1])
mix <- as.numeric(colnames(elecsys71)[elecsys71[3,]==1])

plot(seasia71[seasia71$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(seasia71[match(maj, seasia71$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(seasia71[seasia71$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(seasia71[match(pr, seasia71$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(seasia71[seasia71$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(seasia71[match(mix, seasia71$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1971", 1, cex=1)

# 1961 map Southeast Asia
par(mar=c(1,0.1, 0.1, 0.1))
seasia61 <- world61[world61$COWCODE >=750 & world61$COWCODE <=860,]
plot(seasia61, lwd=1)

maj <- as.numeric(colnames(elecsys61)[elecsys61[1,]==1])
pr <- as.numeric(colnames(elecsys61)[elecsys61[2,]==1])
mix <- as.numeric(colnames(elecsys61)[elecsys61[3,]==1])

plot(seasia61[seasia61$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(seasia61[match(maj, seasia61$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(seasia61[seasia61$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(seasia61[match(pr, seasia61$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(seasia61[seasia61$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(seasia61[match(mix, seasia61$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1961", 1, cex=1)

# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.77, 1.15, legend=c("Majoritarian", "PR", "Mixed", "Autocratic"),
		fill=c("grey30", "grey90", "grey60", "white"),
		#angle=c(45, 135, 90, 0),
		#density=c(20, 20, 20, 0),
		bty="o",
		box.col="black",
		cex=.8,
		ncol=1
)

#############################################################
### Figure 12
## Data Prep
## East Asia
# Prepare map
layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow=T), heights=c(3,3,3))
par(mar=c(1,0.1, 0.1, 0.1))
op <- par(no.readonly=TRUE) 

## Graph
# 2011 map East Asia
par(mar=c(1,0.1, 0.1, 0.1))

easia08 <- world08[world08$COWCODE >=710 & world08$COWCODE <=740,]


plot(easia08, lwd=1)

maj <- as.numeric(colnames(elecsys11)[elecsys11[1,]==1])
pr <- as.numeric(colnames(elecsys11)[elecsys11[2,]==1])
mix <- as.numeric(colnames(elecsys11)[elecsys11[3,]==1])

plot(easia08[easia08$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(easia08[match(maj, easia08$COWCODE),], density=20, angle=45, lwd=0.08,  add=T) # add maj stripes
#plot(easia08[easia08$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(easia08[match(pr, easia08$COWCODE),], density=20, angle=135, lwd=0.08,  add=T) # add pr stripes
plot(easia08[easia08$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(easia08[match(mix, easia08$COWCODE),], density=20, angle=90, lwd=0.08,  add=T) # add mix stripes

mtext("2011", 1, cex=1)


# 2001 map East Asia
par(mar=c(1,0.1, 0.1, 0.1))
easia01 <- world01[world01$COWCODE >=710 & world01$COWCODE <=740,]
plot(easia01, lwd=1)

maj <- as.numeric(colnames(elecsys01)[elecsys01[1,]==1])
pr <- as.numeric(colnames(elecsys01)[elecsys01[2,]==1])
mix <- as.numeric(colnames(elecsys01)[elecsys01[3,]==1])

plot(easia01[easia01$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(easia01[match(maj, easia01$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(easia01[easia01$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(easia01[match(pr, easia01$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(easia01[easia01$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(easia01[match(mix, easia01$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("2001", 1, cex=1)


# 1991 map East Asia
par(mar=c(1,0.1, 0.1, 0.1))
easia91 <- world91[world91$COWCODE >=710 & world91$COWCODE <=740,]
plot(easia91, lwd=1)

maj <- as.numeric(colnames(elecsys91)[elecsys91[1,]==1])
pr <- as.numeric(colnames(elecsys91)[elecsys91[2,]==1])
mix <- as.numeric(colnames(elecsys91)[elecsys91[3,]==1])

plot(easia91[easia91$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(easia91[match(maj, easia91$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(easia91[easia91$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(easia91[match(pr, easia91$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(easia91[easia91$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(easia91[match(mix, easia91$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1991", 1, cex=1)

# 1981 map East Asia
par(mar=c(1,0.1, 0.1, 0.1))
easia81 <- world81[world81$COWCODE >=710 & world81$COWCODE <=740,]
plot(easia81, lwd=1)

maj <- as.numeric(colnames(elecsys81)[elecsys81[1,]==1])
pr <- as.numeric(colnames(elecsys81)[elecsys81[2,]==1])
mix <- as.numeric(colnames(elecsys81)[elecsys81[3,]==1])

plot(easia81[easia81$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(easia81[match(maj, easia81$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(easia81[easia81$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(easia81[match(pr, easia81$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(easia81[easia81$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(easia81[match(mix, easia81$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1981", 1, cex=1)

# 1971 map East Asia
par(mar=c(1,0.1, 0.1, 0.1))
easia71 <- world71[world71$COWCODE >=710 & world71$COWCODE <=740,]
plot(easia71, lwd=1)

maj <- as.numeric(colnames(elecsys71)[elecsys71[1,]==1])
pr <- as.numeric(colnames(elecsys71)[elecsys71[2,]==1])
mix <- as.numeric(colnames(elecsys71)[elecsys71[3,]==1])

plot(easia71[easia71$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(easia71[match(maj, easia71$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(easia71[easia71$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(easia71[match(pr, easia71$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(easia71[easia71$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(easia71[match(mix, easia71$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1971", 1, cex=1)

# 1961 map East Asia
par(mar=c(1,0.1, 0.1, 0.1))
easia61 <- world61[world61$COWCODE >=710 & world61$COWCODE <=740,]
plot(easia61, lwd=1)

maj <- as.numeric(colnames(elecsys61)[elecsys61[1,]==1])
pr <- as.numeric(colnames(elecsys61)[elecsys61[2,]==1])
mix <- as.numeric(colnames(elecsys61)[elecsys61[3,]==1])

plot(easia61[easia61$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(easia61[match(maj, easia61$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(easia61[easia61$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(easia61[match(pr, easia61$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(easia61[easia61$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(easia61[match(mix, easia61$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1961", 1, cex=1)

# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.85, 1.2, legend=c("Majoritarian", "PR", "Mixed", "Autocratic"),
		fill=c("grey30", "grey90", "grey60", "white"),
		#angle=c(45, 135, 90, 0),
		#density=c(20, 20, 20, 0),
		bty="o",
		box.col="black",
		cex=.8,
		ncol=1
)

#############################################################
### Figure 13
## Data Prep
## Sub-Saharan Africa
# Prepare map
layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow=T), heights=c(3,3,3))
par(mar=c(1,0.1, 0.1, 0.1))
op <- par(no.readonly=TRUE) 

## Graph
# 2011 map Sub-Saharan Africa
par(mar=c(1,0.1, 0.1, 0.1))

ssafr08 <- world08[world08$COWCODE >=400 & world08$COWCODE <=599,]


plot(ssafr08, lwd=1)

maj <- as.numeric(colnames(elecsys11)[elecsys11[1,]==1])
pr <- as.numeric(colnames(elecsys11)[elecsys11[2,]==1])
mix <- as.numeric(colnames(elecsys11)[elecsys11[3,]==1])

plot(ssafr08[ssafr08$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(ssafr08[match(maj, ssafr08$COWCODE),], density=20, angle=45, lwd=0.08,  add=T) # add maj stripes
#plot(ssafr08[ssafr08$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(ssafr08[match(pr, ssafr08$COWCODE),], density=20, angle=135, lwd=0.08,  add=T) # add pr stripes
plot(ssafr08[ssafr08$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(ssafr08[match(mix, ssafr08$COWCODE),], density=20, angle=90, lwd=0.08,  add=T) # add mix stripes

mtext("2011", 1, cex=1)


# 2001 map Sub-Saharan Africa
par(mar=c(1,0.1, 0.1, 0.1))
ssafr01 <- world01[world01$COWCODE >=400 & world01$COWCODE <=599,]
plot(ssafr01, lwd=1)

maj <- as.numeric(colnames(elecsys01)[elecsys01[1,]==1])
pr <- as.numeric(colnames(elecsys01)[elecsys01[2,]==1])
mix <- as.numeric(colnames(elecsys01)[elecsys01[3,]==1])

plot(ssafr01[ssafr01$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(ssafr01[match(maj, ssafr01$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
plot(ssafr01[ssafr01$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(ssafr01[match(pr, ssafr01$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
plot(ssafr01[ssafr01$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(ssafr01[match(mix, ssafr01$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("2001", 1, cex=1)


# 1991 map Sub-Saharan Africa
par(mar=c(1,0.1, 0.1, 0.1))
ssafr91 <- world91[world91$COWCODE >=400 & world91$COWCODE <=599,]
plot(ssafr91, lwd=1)

maj <- as.numeric(colnames(elecsys91)[elecsys91[1,]==1])
pr <- as.numeric(colnames(elecsys91)[elecsys91[2,]==1])
mix <- as.numeric(colnames(elecsys91)[elecsys91[3,]==1])

plot(ssafr91[ssafr91$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(ssafr91[match(maj, ssafr91$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(ssafr91[ssafr91$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(ssafr91[match(pr, ssafr91$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(ssafr91[ssafr91$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(ssafr91[match(mix, ssafr91$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1991", 1, cex=1)

# 1981 map Sub-Saharan Africa
par(mar=c(1,0.1, 0.1, 0.1))
ssafr81 <- world81[world81$COWCODE >=400 & world81$COWCODE <=599,]
plot(ssafr81, lwd=1)

maj <- as.numeric(colnames(elecsys81)[elecsys81[1,]==1])
pr <- as.numeric(colnames(elecsys81)[elecsys81[2,]==1])
mix <- as.numeric(colnames(elecsys81)[elecsys81[3,]==1])

plot(ssafr81[ssafr81$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(ssafr81[match(maj, ssafr81$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(ssafr81[ssafr81$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(ssafr81[match(pr, ssafr81$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(ssafr81[ssafr81$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(ssafr81[match(mix, ssafr81$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1981", 1, cex=1)

# 1971 map Sub-Saharan Africa
par(mar=c(1,0.1, 0.1, 0.1))
ssafr71 <- world71[world71$COWCODE >=400 & world71$COWCODE <=599,]
plot(ssafr71, lwd=1)

maj <- as.numeric(colnames(elecsys71)[elecsys71[1,]==1])
pr <- as.numeric(colnames(elecsys71)[elecsys71[2,]==1])
mix <- as.numeric(colnames(elecsys71)[elecsys71[3,]==1])

plot(ssafr71[ssafr71$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(ssafr71[match(maj, ssafr71$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(ssafr71[ssafr71$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(ssafr71[match(pr, ssafr71$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(ssafr71[ssafr71$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(ssafr71[match(mix, ssafr71$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1971", 1, cex=1)

# 1961 map Sub-Saharan Africa
par(mar=c(1,0.1, 0.1, 0.1))
ssafr61 <- world61[world61$COWCODE >=400 & world61$COWCODE <=599,]
plot(ssafr61, lwd=1)

maj <- as.numeric(colnames(elecsys61)[elecsys61[1,]==1])
pr <- as.numeric(colnames(elecsys61)[elecsys61[2,]==1])
mix <- as.numeric(colnames(elecsys61)[elecsys61[3,]==1])

#plot(ssafr61[ssafr61$COWCODE%in%maj,], col="grey30",  add=T) # add maj color
#plot(ssafr61[match(maj, ssafr61$COWCODE),], density=20, angle=45, lwd=0.01,  add=T) # add maj stripes
#plot(ssafr61[ssafr61$COWCODE%in%pr,], col="grey90",  add=T) # add PR color
#plot(ssafr61[match(pr, ssafr61$COWCODE),], density=20, angle=135, lwd=0.01,  add=T) # add pr stripes
#plot(ssafr61[ssafr61$COWCODE%in%mix,], col="grey60",  add=T) # add mix color
#plot(ssafr61[match(mix, ssafr61$COWCODE),], density=20, angle=90, lwd=0.01,  add=T) # add mix stripes

mtext("1961", 1, cex=1)

# Prepare for legend
par(op) # return pre-plotting standard values (delete x/y limits)
par(xpd=TRUE)  # Do not clip legend to the drawing area
par(mfrow=c(1,1)) # Do not stick to the current plot but go back to the entire window !!!!

# Legend
par(mar=c(.1,5.1,.1,2.1))
par(new=TRUE)
plot(1, 1, type = "n", axes = F,  xlab = "", ylab = "") # call empty plot

legend(.85, 1.2, legend=c("Majoritarian", "PR", "Mixed", "Autocratic"),
		fill=c("grey30", "grey90", "grey60", "white"),
		#angle=c(45, 135, 90, 0),
		#density=c(20, 20, 20, 0),
		bty="o",
		box.col="black",
		cex=.8,
		ncol=1
)





